#ifndef NT2_INCLUDE_FUNCTIONS_ISMATRIX_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ISMATRIX_HPP_INCLUDED

#include <nt2/predicates/include/functions/ismatrix.hpp>

#endif
